==> datasets-1.4.1.tar.gz: datasets-1.4.1/datasets/wiki_atomic_edits/README.md <==
---
annotations_creators:
- found
language_creators:
- found
languages:
  german_insertions:
  - de
  german_deletions:
  - de
  english_insertions:
  - en
  english_deletions:
  - en
  spanish_insertions:
  - es
  spanish_deletions:
  - es
  french_insertions:
  - fr
  french_deletions:
  - fr
  italian_insertions:
  - it
  italian_deletions:
  - it
  japanese_insertions:
  - jp
  japanese_deletions:
  - jp
  russian_insertions:
  - ru
  russian_deletions:
  - ru
  chinese_insertions:
  - zh
  chinese_deletions:
  - zh
licenses:
- cc-by-sa-4.0
multilinguality:
- multilingual
size_categories:
- n>1M
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- explanation-generation
- summarization
---

# Dataset Card Creation Guide

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-instances)
  - [Data Splits](#data-instances)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** None
- **Repository:** https://github.com/google-research-datasets/wiki-atomic-edits
- **Paper:** https://www.aclweb.org/anthology/D18-1028/
- **Leaderboard:** [More Information Needed]
- **Point of Contact:** [More Information Needed]

### Dataset Summary

[More Information Needed]

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

[More Information Needed]

## Dataset Structure

### Data Instances

Here are some examples of questions and facts:


### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

[More Information Needed]

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

[More Information Needed]

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

[More Information Needed]

### Contributions

Thanks to [@abhishekkrthakur](https://github.com/abhishekkrthakur) for adding this dataset.

==> datasets-1.6.2.tar.gz: datasets-1.6.2/datasets/wiki_atomic_edits/README.md <==
---
annotations_creators:
- found
language_creators:
- found
languages:
  german_insertions:
  - de
  german_deletions:
  - de
  english_insertions:
  - en
  english_deletions:
  - en
  spanish_insertions:
  - es
  spanish_deletions:
  - es
  french_insertions:
  - fr
  french_deletions:
  - fr
  italian_insertions:
  - it
  italian_deletions:
  - it
  japanese_insertions:
  - jp
  japanese_deletions:
  - jp
  russian_insertions:
  - ru
  russian_deletions:
  - ru
  chinese_insertions:
  - zh
  chinese_deletions:
  - zh
licenses:
- cc-by-sa-4.0
multilinguality:
- multilingual
size_categories:
  chinese_deletions:
  - 100K<n<1M
  chinese_insertions:
  - 100K<n<1M
  english_deletions:
  - 1M<n<10M
  english_insertions:
  - 10M<n<100M
  french_deletions:
  - 1M<n<10M
  french_insertions:
  - 1M<n<10M
  german_deletions:
  - 1M<n<10M
  german_insertions:
  - 1M<n<10M
  italian_deletions:
  - 100K<n<1M
  italian_insertions:
  - 1M<n<10M
  japanese_deletions:
  - 1M<n<10M
  japanese_insertions:
  - 1M<n<10M
  russian_deletions:
  - 100K<n<1M
  russian_insertions:
  - 1M<n<10M
  spanish_deletions:
  - 100K<n<1M
  spanish_insertions:
  - 1M<n<10M
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- explanation-generation
- summarization
---

# Dataset Card Creation Guide

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-instances)
  - [Data Splits](#data-instances)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** None
- **Repository:** https://github.com/google-research-datasets/wiki-atomic-edits
- **Paper:** https://www.aclweb.org/anthology/D18-1028/
- **Leaderboard:** [More Information Needed]
- **Point of Contact:** [More Information Needed]

### Dataset Summary

[More Information Needed]

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

[More Information Needed]

## Dataset Structure

### Data Instances

Here are some examples of questions and facts:


### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

[More Information Needed]

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

[More Information Needed]

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

[More Information Needed]

### Contributions

Thanks to [@abhishekkrthakur](https://github.com/abhishekkrthakur) for adding this dataset.
